/* Webolize IssueTracker and Webolize Core
 * Copyright (C) 2007 Webolize LLC
 * http://www.webolize.com
 * 
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 */

IF NOT EXISTS(SELECT name 
	  FROM 	 sysobjects 
	  WHERE  name = N'webolize_projects' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_projects](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[fk_siteId] [int] NULL,
		[forum_type] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[forum_type_version] [int] NULL,
		[forum_name] [nvarchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[description] [nvarchar](200) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[short_name] [nvarchar](12) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[fk_department] [int] NULL,
		[created_date] [datetime] NULL,
		[created_by] [int] NULL,
		[closed_date] [datetime] NULL,
		[closed_by] [int] NULL,
		[closed] [bit] NULL,
		[contact_person] [int] NULL,
		[contact_department] [int] NULL,
		[department_account] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[group_managers] [int] NULL,
		[group_producers] [int] NULL,
		[group_viewers] [int] NULL,
		[fk_issue] [int] NOT NULL,
		[forum_settings] [nvarchar](max) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_projects] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_projects_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [DF_webolize_projects_closed]  DEFAULT ((0)) FOR [closed],
		CONSTRAINT [DF_webolize_projects_fk_issue]  DEFAULT ((-1)) FOR [fk_issue],
		CONSTRAINT [DF_webolize_projects_contact_person]  DEFAULT ((-1)) FOR [contact_person],
		CONSTRAINT [DF_webolize_projects_fk_department]  DEFAULT ((-1)) FOR [fk_department],
		CONSTRAINT [DF_webolize_projects_group_managers]  DEFAULT ((-1)) FOR [group_managers],
		CONSTRAINT [DF_webolize_projects_group_producers]  DEFAULT ((-1)) FOR [group_producers],
		CONSTRAINT [DF_webolize_projects_group_viewers]  DEFAULT ((-1)) FOR [group_viewers],
		CONSTRAINT [PK_webolize_projects_id] PRIMARY KEY CLUSTERED 
		(
			[pk_id]
		)  ON [PRIMARY] 

END

IF NOT EXISTS(SELECT name 
	  FROM 	 sysobjects 
	  WHERE  name = N'webolize_attributes' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_attributes](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[parent_attribute] [int] NOT NULL,
		[fk_site] [int] NOT NULL,
		[fk_forum] [int] NOT NULL,
		[fk_section] [int] NOT NULL,
		[fk_user] [int] NOT NULL,
		[application] [varchar](64) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[attribute_type] [varchar](32) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[name] [nvarchar](128) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[value] [nvarchar](128) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[active] [bit] NULL,
		[ordering] [int] NULL,
		[created_by] [int] NULL,
		[created_date] [datetime] NULL
	) ON [PRIMARY]


	ALTER TABLE [dbo].[webolize_attributes] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_attributes_parent_attribute]  DEFAULT ((-1)) FOR [parent_attribute],
		CONSTRAINT [DF_webolize_attributes_fk_site]  DEFAULT ((-1)) FOR [fk_site],
		CONSTRAINT [DF_webolize_attributes_fk_forum]  DEFAULT ((-1)) FOR [fk_forum],
		CONSTRAINT [DF_webolize_attributes_fk_section]  DEFAULT ((-1)) FOR [fk_section],
		CONSTRAINT [DF_webolize_attributes_fk_user]  DEFAULT ((-1))	FOR [fk_user],
		CONSTRAINT [DF_webolize_attributes_active]  DEFAULT ((1)) FOR [active],
		CONSTRAINT [DF_webolize_attributes_ordering]  DEFAULT ((10)) FOR [ordering],
		CONSTRAINT [DF_webolize_attributes_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [PK_webolize_attributes_id] PRIMARY KEY CLUSTERED 
		(
			[pk_id]
		)  ON [PRIMARY] 

-- priorities
INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','PRIORITY','Blocker','Blocks development, testing or production',1,1,10)

INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','PRIORITY','Critical','Crashes, loss of data or value',1,1,20)

INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','PRIORITY','Major','Major loss of function',1,1,30)

INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','PRIORITY','Minor','Minor loss of function but easy workaround exists',1,1,40)

INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','PRIORITY','Trivial','Cosmetic problems',1,1,50)

-- statuses
INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','STATUS','Open','Open',1,1,100)

INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','STATUS','In Progress','In Progress',1,1,80)

INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','STATUS','Resolved','Resolved',1,1,70)

INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','STATUS','Reopened','Reopened',1,1,60)

INSERT INTO [dbo].[webolize_attributes]
			([application],[attribute_type],[name],[value],[active],[created_by],[ordering])
	VALUES	('Webolize-IssueTracker','STATUS','Closed','Closed',1,1,50)

END

GO

IF NOT EXISTS(SELECT name 
	  FROM 	 sysobjects 
	  WHERE  name = N'webolize_issues' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_issues](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[issue_type] [varchar](64) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[fk_project] [int] NOT NULL,
		[title] [nvarchar](254) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[subject] [nvarchar](254) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[parent_issue] [int] NULL,
		[related_topics_count] [int] NULL,
		[fk_initial_thought] [int] NOT NULL,
		[assigned_to] [int] NULL,
		[complete] [bit] NOT NULL,
		[completed_by] [int] NULL,
		[completed_date] [datetime] NULL,
		[due_date] [datetime] NULL,
		[closed] [bit] NOT NULL,
		[closed_by] [int] NULL,
		[closed_date] [datetime] NULL,
		[created_by] [int] NOT NULL,
		[created_date] [datetime] NOT NULL,
		[topic_settings] [nvarchar](4000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL
	) ON [PRIMARY]


	ALTER TABLE [dbo].[webolize_issues] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_issues_issue_type]  DEFAULT ('Webolize.Core.Topic') FOR [issue_type],
		CONSTRAINT [DF_webolize_issues_fk_project]  DEFAULT ((-1)) FOR [fk_project],
		CONSTRAINT [DF_webolize_issues_parent_issue]  DEFAULT ((-1)) FOR [parent_issue],
		CONSTRAINT [DF_webolize_issues_related_topics_count]  DEFAULT ((0)) FOR [related_topics_count],
		CONSTRAINT [DF_webolize_issues_fk_initial_thought]  DEFAULT ((-1)) FOR [fk_initial_thought],
		CONSTRAINT [DF_webolize_issues_assigned_to]  DEFAULT ((-1)) FOR [assigned_to],
		CONSTRAINT [DF_webolize_issues_complete]  DEFAULT ((0)) FOR [complete],
		CONSTRAINT [DF_webolize_issues_completed_by]  DEFAULT ((-1)) FOR [completed_by],
		CONSTRAINT [DF_webolize_issues_closed]  DEFAULT ((0)) FOR [closed],
		CONSTRAINT [DF_webolize_issues_closed_by]  DEFAULT ((-1)) FOR [closed_by],
		CONSTRAINT [DF_webolize_issues_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [DF_webolize_issues_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [PK_webolize_issues] PRIMARY KEY CLUSTERED 
		(
			[pk_id]
		)  ON [PRIMARY] 
END

GO

IF NOT EXISTS(SELECT name 
	  FROM 	 sysobjects 
	  WHERE  name = N'webolize_issuedetails' 
	  AND 	 type = 'U')
BEGIN
	CREATE TABLE [dbo].[webolize_issuedetails](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[fk_issue] [int] NOT NULL,
		[thought_type] [varchar](64) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[has_attachments] [bit] NOT NULL,
		[private] [bit] NOT NULL,
		[thought_content] [nvarchar](4000) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[created_by_ipaddress] [varchar](32) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[created_by] [int] NOT NULL,
		[created_date] [datetime] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_issuedetails] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_issuedetails_fk_issue]  DEFAULT ((-1)) FOR [fk_issue],
		CONSTRAINT [DF_webolize_issuedetails_thought_type]  DEFAULT ('Webolize.Core.Thought') FOR [thought_type],
		CONSTRAINT [DF_webolize_issuedetails_has_attachments]  DEFAULT ((0)) FOR [has_attachments],
		CONSTRAINT [DF_webolize_issuedetails_private]  DEFAULT ((0)) FOR [private],
		CONSTRAINT [DF_webolize_issuedetails_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [DF_webolize_issuedetails_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [PK_webolize_issuedetails] PRIMARY KEY CLUSTERED 
		(
			[pk_id]
		)  ON [PRIMARY] 
END
GO

IF NOT EXISTS(SELECT name 
	  FROM 	 sysobjects 
	  WHERE  name = N'webolize_issue_attribute' 
	  AND 	 type = 'U')
BEGIN

	CREATE TABLE [dbo].[webolize_issue_attribute](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[fk_issue] [int] NOT NULL,
		[fk_attribute] [int] NOT NULL,
		[created_by] [int] NOT NULL,
		[created_date] [datetime] NOT NULL,
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_issue_attribute] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_issue_attribute_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [PK_webolize_issue_attribute] PRIMARY KEY CLUSTERED
		(
			[pk_id]
		)  ON [PRIMARY] 

END
GO

IF NOT EXISTS(SELECT name 
	  FROM 	 sysobjects 
	  WHERE  name = N'webolize_files'
	  AND 	 type = 'U')
BEGIN

	CREATE TABLE [dbo].[webolize_files](
		[pk_id] [int] IDENTITY(1,1) NOT NULL,
		[fk_project] [int] NOT NULL,
		[fk_issue] [int] NOT NULL,
		[filepath] [varchar](255) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
		[display_name] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NOT NULL,
		[title] [nvarchar](100) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[filesize] [int] NOT NULL,
		[nrofdownloads] [int] NOT NULL,
		[contenttype] [varchar](50) COLLATE SQL_Latin1_General_CP1_CI_AS NULL,
		[created_by] [int] NOT NULL,
		[created_date] [datetime] NOT NULL
	) ON [PRIMARY]

	ALTER TABLE [dbo].[webolize_files] WITH NOCHECK ADD 
		CONSTRAINT [DF_webolize_files_fk_project]  DEFAULT ((-1)) FOR [fk_project],
		CONSTRAINT [DF_webolize_files_fk_issue]  DEFAULT ((-1)) FOR [fk_issue],
		CONSTRAINT [DF_webolize_files_filesize]  DEFAULT ((-1)) FOR [filesize],
		CONSTRAINT [DF_webolize_files_nrofdownloads]  DEFAULT ((0)) FOR [nrofdownloads],
		CONSTRAINT [DF_webolize_files_created_by]  DEFAULT ((-1)) FOR [created_by],
		CONSTRAINT [DF_webolize_files_created_date]  DEFAULT (getdate()) FOR [created_date],
		CONSTRAINT [PK_webolize_files] PRIMARY KEY CLUSTERED
		(
			[pk_id]
		)  ON [PRIMARY] 

END
GO


-- CUYAHOGA SPECIFIC
--
--  Table data
--
SET DATEFORMAT ymd

DECLARE @moduletypeid int

INSERT INTO cuyahoga_moduletype (name, assemblyname, classname, path, editpath, inserttimestamp, updatetimestamp) 
	VALUES ('Webolize-IssueTracker', 'Webolize.IssueTracker', 'Webolize.IssueTracker.IssueTrackerModule', 'Modules/Webolize-IssueTracker/MyIssues.ascx', 'Modules/Webolize-IssueTracker/Admin/Admin.aspx', '2007-06-05 12:00:00', '2007-06-05 12:00:00')

SELECT @moduletypeid = Scope_Identity()

INSERT INTO cuyahoga_modulesetting (moduletypeid, name, friendlyname, settingdatatype, iscustomtype, isrequired) VALUES (@moduletypeid, 'TIMETRACKER_SECTION', 'Section ID of TimeTracker (or -1)', 'System.Int16', 0, 1)
GO

INSERT INTO cuyahoga_version (assembly, major, minor, patch) VALUES ('Webolize.IssueTracker', 0, 8, 0)
go
